# Generated by Django 4.2.6 on 2023-10-24 10:04

from django.db import migrations, models
import django.db.models.deletion
import django_anchor_modeling.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('metadata', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BusinessToDataFieldMap',
            fields=[
                ('created', models.DateTimeField(auto_now_add=True)),
                ('id', django_anchor_modeling.fields.BusinessIdentifierField(max_length=255, primary_key=True, serialize=False)),
                ('description', models.TextField()),
                ('map', models.JSONField(default=dict)),
                ('metadata', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='metadata.datachange')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
