# Generated by Django 4.2.6 on 2023-10-29 01:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dataviewer', '0002_businesstodatafieldmap_main_model_class'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='businesstodatafieldmap',
            name='metadata',
        ),
    ]
