# Generated by Django 4.2.6 on 2023-10-28 19:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dataviewer', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='businesstodatafieldmap',
            name='main_model_class',
            field=models.CharField(max_length=255, null=True),
        ),
    ]
